@@ -37,7 +37,7 @@ var files_dup =
     [ "pipewire.h", "pipewire_8h.html", "pipewire_8h" ],
     [ "port.c", "port_8c.html", "port_8c" ],
     [ "port.h", "port_8h.html", "port_8h" ],
-    [ "properties.c", "properties_8c.html", null ],
+    [ "properties.c", "properties_8c.html", "properties_8c" ],
     [ "properties.h", "properties_8h.html", "properties_8h" ],
     [ "protocol.c", "protocol_8c.html", "protocol_8c" ],
     [ "protocol.h", "protocol_8h.html", "protocol_8h" ],
